@@ -48,7 +48,7 @@ lpint_gettext (const char *str)
 
 #define LP_GET_HELP_ITEM_LABEL   N_("Get Help Online...")
 #define LP_TRANSLATE_ITEM_LABEL  N_("Translate This Application...")
-#define LP_REPORT_BUG_ITEM_LABEL N_("Report a Problem")
+#define LP_REPORT_BUG_ITEM_LABEL N_("Report a Problem...")
 
 
 /* ------------------------------ */
@@ -199,8 +199,10 @@ launchpad_integration_add_bonobo_ui (BonoboUIComponent *ui, const gchar *path)
 				"lpi-translate",
 				lpint_bonobo_show_translations_cb);
 
+#if 0
     lpint_bonobo_add_menu_item (ui, path, "LpShowBugs",
 				LP_REPORT_BUG_ITEM_LABEL, 0,
 				"lpi-bug",
 				lpint_bonobo_show_bugs_cb);
+#endif
 }
